@@ -46,7 +46,7 @@ any other package maintainer - I want to ensure the package is as accessible and
 useful as possible.
      
 """
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 __package__ = 'amos'
 
@@ -57,8 +57,7 @@ from .base.bunches import *
 from .base.mappings import *
 from .base.sequences import *
 from .construct.configuration import *
-from .construct.create import *
-from .construct.filing import *
+from .construct.factories import *
 from .construct.lazy import *
 from .core.check import *
 from .core.composites import *
@@ -71,6 +70,8 @@ from .observe.module import *
 from .observe.package import *
 from .observe.registries import *
 from .observe.traits import *
+from .project.settings import *
+from .project.filing import *
 from .repair.convert import *
 from .repair.modify import *
 from .repair.validate import *
