@@ -22,13 +22,16 @@ Contents:
     Catalog (Dictionary): wildcard-accepting dict which is primarily intended 
         for storing different options and strategies. It also returns lists of 
         matches if a list of keys is provided.
- 
+    Library (MutableMapping): a chained mapping used to registering subclasses
+        and instances.
+        
 ToDo:
 
        
 """
 from __future__ import annotations
-from collections.abc import Hashable, Iterator, Mapping, MutableMapping, Sequence
+from collections.abc import (
+    Hashable, Iterator, Mapping, MutableMapping, Sequence)
 import copy
 import dataclasses
 import inspect
@@ -387,14 +390,12 @@ class Library(MutableMapping):
             Catalog.
         instances (Catalog): a catalog of stored class instances. Defaults to an
             empty Catalog.
-    
-    Attributes:
-        maps (list[Catalog]): the ordered mappings to search, as required from
-             inheriting from ChainMap.
                  
     """
-    classes: Catalog = dataclasses.field(default_factory = dict)
-    instances: Catalog = dataclasses.field(default_factory = dict)
+    classes: Catalog[str, Type[Any]] = dataclasses.field(
+        default_factory = Catalog)
+    instances: Catalog[str, object] = dataclasses.field(
+        default_factory = Catalog)
         
     """ Public Methods """
     
