@@ -16,7 +16,7 @@ License: Apache-2.0
     See the License for the specific language governing permissions and
     limitations under the License.
 
-Classes:
+Contents:
     System (Graph): a lightweight directed acyclic graph (DAG). Internally, the 
         graph is stored as an adjacency list. As a result, it should primarily 
         be used for workflows or other uses that do require large graphs.
@@ -169,13 +169,15 @@ class System(Adjacency):
     """Directed graph with unweighted edges.
     
     Args:
-        contents (MutableMapping[composites.Node, Set[composites.Node]]): keys are nodes and 
-            values are sets of nodes (or hashable representations of nodes). 
-            Defaults to a defaultdict that has a set for its value format.
+        contents (MutableMapping[composites.Node, Set[composites.Node]]): keys 
+            are nodes and values are sets of nodes (or hashable representations 
+            of nodes). Defaults to a defaultdict that has a set for its value 
+            format.
                   
     """  
-    contents: MutableMapping[composites.Node, Set[composites.Node]] = dataclasses.field(
-        default_factory = lambda: collections.defaultdict(set))
+    contents: MutableMapping[composites.Node, Set[composites.Node]] = (
+        dataclasses.field(
+            default_factory = lambda: collections.defaultdict(set)))
     
     """ Properties """
 
